Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1557)

Unified Diff: third_party/apple_apsl/malloc.h

Issue 7471041: Update OOM killer with Lion info. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/apple_apsl/README.chromium ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/apple_apsl/malloc.h
diff --git a/third_party/apple_apsl/malloc.h b/third_party/apple_apsl/malloc.h
index a5a409f248094472a8d9fa4d51ead64410d36d7c..9fd1d5d4708a9c3d7cb3e023fadea7f798649871 100644
--- a/third_party/apple_apsl/malloc.h
+++ b/third_party/apple_apsl/malloc.h
@@ -45,11 +45,14 @@ typedef struct _ChromeMallocZone {
struct malloc_introspection_t *introspect;
unsigned version;
- /* aligned memory allocation. The callback may be NULL. */
- void *(*memalign)(struct _malloc_zone_t *zone, size_t alignment, size_t size); // version >= 5
+ /* aligned memory allocation. The callback may be NULL. Present in version >= 5. */
+ void *(*memalign)(struct _malloc_zone_t *zone, size_t alignment, size_t size);
- /* free a pointer known to be in zone and known to have the given size. The callback may be NULL. */
- void (*free_definite_size)(struct _malloc_zone_t *zone, void *ptr, size_t size); // version >= 6
+ /* free a pointer known to be in zone and known to have the given size. The callback may be NULL. Present in version >= 6.*/
+ void (*free_definite_size)(struct _malloc_zone_t *zone, void *ptr, size_t size);
+
+ /* Empty out caches in the face of memory pressure. The callback may be NULL. Present in version >= 8. */
+ size_t (*pressure_relief)(struct _malloc_zone_t *zone, size_t goal);
} ChromeMallocZone;
#endif // THIRD_PARTY_APPLE_APSL_MALLOC_H_
« no previous file with comments | « third_party/apple_apsl/README.chromium ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698